@@ -1,7 +1,7 @@
 import sys
 import os
 import platform
-from rook.exceptions.tool_exceptions import RookDependencyError
+from rook.exceptions import RookDependencyError
 
 PLATFORM = sys.platform
 CPYTHON = platform.python_implementation() == 'CPython'
@@ -42,7 +42,7 @@ if PLATFORM in ('darwin', 'linux2', 'linux'):
         native_extensions.python_fork_handler_called = 0
 
         try:
-            from .singleton import singleton_obj
+            from .singleton import singleton_obj  # lgtm[py/cyclic-import]
 
             if pid == 0:
                 # child
@@ -89,3 +89,6 @@ if PLATFORM in ('darwin', 'linux2', 'linux'):
 else:
     def install_fork_handler(fork):
         pass
+
+    def remove_fork_handler():
+        pass
