@@ -83,4 +83,5 @@ class Aug(object):
                     UserWarnings.set_error(Error(exc=RookRuleMaxExecutionTimeReached()))
                     self._enabled = False
 
-        self._limit_manager.try_with_limits(now_ns, aug_core)
+        should_skip_limiters = (not self._executed) and (self._condition is None)
+        self._limit_manager.try_with_limits(now_ns, aug_core, should_skip_limiters)
