@@ -1,5 +1,5 @@
 import os
-from rook.com_ws.multithread.agent_com_ws import AgentCom as AgentComMT
+from rook.com_ws.agent_com_impel.multithread_agent_com import MultiThreadAgentCom as AgentComMT
 from rook.logger import logger
 from sys import platform
 
@@ -10,7 +10,7 @@ thread_connection_type = None
 
 if os.getenv("ROOKOUT_SINGLETHREAD_COMM", "0") == "1":
     if platform in ("linux", "linux2"):
-        from rook.com_ws.singlethread.agent_com_ws import AgentCom as AgentComSingle
+        from rook.com_ws.agent_com_impel.singlethread_agent_com import SingleThreadAgentCom as AgentComSingle
 
         logger.info("Using single-threaded communication")
         AgentCom = AgentComSingle
