@@ -12,7 +12,7 @@ class SelectableEvent(object):
     def __init__(self):
         self._event = Event()
         self._readsocket, self._writesocket = socket.socketpair()
-        self._readwaiter = poll_select.Waiter([self._readsocket], [], [])
+        self._readwaiter = poll_select.get_waiter([self._readsocket], [], [])
 
     def close(self):
         self._readsocket.close()
