@@ -11,7 +11,7 @@ namespace native_extensions {
         if (python_fork_handler_called != NULL) {
             if (PyLong_AsLong(python_fork_handler_called) != 1) {
                 printf("[Rookout] Rookout does not support running in forking processes. Please start rook only after forking\n"
-                       " For more information, see https://docs.rookout.com/docs/sdk-setup.html#pre-forking-servers\n");
+                       " For more information, see https://docs.rookout.com/docs/python-setup#pre-forking-celery-gunicorn-etc\n");
             }
 
             Py_DECREF(python_fork_handler_called);
