@@ -38,7 +38,12 @@ static bool strip_tracebackhide_frames = true;
 
             static PyObject* traceback_hide_string = PyUnicode_FromString("__rookout__tracebackhide__");
 
-            if (PyDict_Contains(frame->f_locals, traceback_hide_string) == 1) {
+#if PY_VERSION_HEX >= 0x030B0000
+            PyObject *locals = PyFrame_GetLocals(frame);
+#else
+            PyObject *locals = frame->f_locals;
+#endif
+            if (PyDict_Contains(locals, traceback_hide_string) == 1) {
                 Py_XINCREF(next);
                 Py_XSETREF(*last_not_hidden_link, next);
                 prev_link = last_not_hidden_link;
@@ -47,6 +52,10 @@ static bool strip_tracebackhide_frames = true;
                 last_not_hidden_link = prev_link;
             }
 
+#if PY_VERSION_HEX >= 0x030B0000
+            Py_DECREF(locals);
+            locals = nullptr;
+#endif
             tb = next;
         }
     done:
