@@ -1,6 +1,3 @@
-import base64
-
-from .namespace import Namespace
 from .python_object_namespace import PythonObjectNamespace
 from .dumped_primitive_namespace import DumpedPrimitiveNamespace
 
