@@ -37,7 +37,7 @@ _MAX_OBJECT_REFERENTS = 1000
 # Object types to ignore when looking for the code objects.
 _BFS_IGNORE_TYPES = (types.ModuleType, type(None), bool, float, six.binary_type,
                      six.text_type, types.BuiltinFunctionType,
-                     types.BuiltinMethodType) + six.integer_types
+                     types.BuiltinMethodType, types.GeneratorType) + six.integer_types
 
 # Maximum length of lists to traverse. This is to prevent lists from being traversed,
 # since with a good chance, lists that contain code objects are short.
@@ -62,12 +62,12 @@ def GetCodeObjectAtLine(module, line):
   prev_line = 0
   next_line = six.MAXSIZE
 
-  for code_object in _GetModuleCodeObjects(module):
-    lines = sorted(list(_GetLineNumbers(code_object)))
+  for code_object_node in _GetModuleCodeObjects(module):
+    lines = sorted(list(_GetLineNumbers(code_object_node.obj)))
 
     for co_line_number in lines:
       if co_line_number == line:
-        return (True, code_object)
+        return (True, code_object_node)
       elif co_line_number < line:
         prev_line = max(prev_line, co_line_number)
       elif co_line_number > line:
@@ -109,6 +109,22 @@ def _GetLineNumbers(code_object):
     yield current_line
 
 
+class BFSNode(object):
+  def __init__(self, obj, parent, grandparent):
+    self.obj = obj
+    self.parent = parent
+    self.grandparent = grandparent
+
+  def __repr__(self):
+    return "<BFSNode> " + repr(self.obj) + " ;;; " + repr(self.parent) + " ;;; " + repr(self.grandparent)
+
+  def get_id(self):
+    if type(self.parent) is tuple:
+      return id(self.grandparent)
+
+    return id(self.parent)
+
+
 def _GetModuleCodeObjects(module):
   """Gets all code objects defined in the specified module.
 
@@ -132,18 +148,18 @@ def _GetModuleCodeObjects(module):
   """
 
   visit_recorder = _VisitRecorder()
-  current = [module]
-  code_objects = set()
+  current = [BFSNode(module, None, None)]
+  code_objects_nodes = set()
   while current:
     current = _FindCodeObjectsReferents(module, current, visit_recorder)
-    code_objects |= current
+    code_objects_nodes |= current
 
     # Unfortunately Python code objects don't implement tp_traverse, so this
     # type can't be used with gc.get_referents. The workaround is to get the
     # relevant objects explicitly here.
-    current = [code_object.co_consts for code_object in current]
+    current = [BFSNode(code_object.obj.co_consts, code_object.obj, code_object.parent) for code_object in current]
 
-  return code_objects
+  return code_objects_nodes
 
 
 def _FindCodeObjectsReferents(module, start_objects, visit_recorder):
@@ -225,19 +241,22 @@ def _FindCodeObjectsReferents(module, start_objects, visit_recorder):
   code_objects = set()
   current = start_objects
   for obj in current:
-    visit_recorder.Record(obj)
+    visit_recorder.Record(obj.obj)
 
   depth = 0
   while current and depth < _MAX_REFERENTS_BFS_DEPTH:
     new_current = []
     for current_obj in current:
-      referents = gc.get_referents(current_obj)
-      if (current_obj is not module.__dict__ and
+      referents = gc.get_referents(current_obj.obj)
+      if (current_obj.obj is not module.__dict__ and
           len(referents) > _MAX_OBJECT_REFERENTS):
         continue
 
       for obj in referents:
         try:
+          if isinstance(obj, BFSNode):
+            continue
+
           if isinstance(obj, _BFS_IGNORE_TYPES) or not visit_recorder.Record(obj):
             continue
 
@@ -250,10 +269,10 @@ def _FindCodeObjectsReferents(module, start_objects, visit_recorder):
           if isinstance(obj, six.class_types) and CheckIgnoreClass(obj):
             continue
 
-          if isinstance(obj, types.CodeType):
-            code_objects.add(obj)
+          if isinstance(obj, types.CodeType) and not isinstance(current_obj.obj, dict):
+            code_objects.add(BFSNode(obj, current_obj.obj, current_obj.parent))
           else:
-            new_current.append(obj)
+            new_current.append(BFSNode(obj, current_obj.obj, current_obj.parent))
 
         except ReferenceError:  # As we are using weak references to iterate, they can disappear
           pass
