@@ -1,5 +1,7 @@
 import sys
 import time
+import six
+from rook.config import LoggingConfiguration
 
 
 def seconds_to_int_nano_seconds(seconds):
@@ -15,6 +17,11 @@ def milliseconds_to_int_nano_seconds(milliseconds):
     return int((10 ** 6) * milliseconds)
 
 
+def quiet_print(msg, *args, **kwargs):
+    if not LoggingConfiguration.QUIET:
+        six.print_(msg, *args, **kwargs)
+
+
 '''
 This trick here allows to check the python version only once when the module is loaded,
 and call get_most_accurate_time_stamp_nano_seconds() to find what is the time stamp.
